==> memsource-cli-3.3.323.tgz: package/lib/create-file-import-settings.js <==
"use strict";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

var axios = require('axios');

var _require = require('./utils'),
    baseUrl = _require.baseUrl,
    authenticate = _require.authenticate;

var _require$setup = require('@cloudflare/cli-helpers').setup({
  cliName: 'memsource-cli'
}),
    bail = _require$setup.bail,
    success = _require$setup.success,
    info = _require$setup.info;

var findConfig = require('find-config');

var config = findConfig.require('memsource.config.js');

var MEMSOURCE_FILE_IMPORT_SETTINGS = config.MEMSOURCE_FILE_IMPORT_SETTINGS;
/**
 * createFileImportSettings
 * Creates settings based on the MEMSOURCE_FILE_IMPORT_SETINGS key
 *
 */

var createFileImportSettings =
/*#__PURE__*/
function () {
  var _ref = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee() {
    var response, token, settingsResponse;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            // Bail if we can't find file settings config key
            if (_typeof(MEMSOURCE_FILE_IMPORT_SETTINGS) === undefined) {
              bail('Missing MEMSOURCE_FILE_IMPORT_SETTINGS in memsource.config.js');
            }

            _context.next = 3;
            return authenticate();

          case 3:
            response = _context.sent;
            token = response.data.token;
            _context.prev = 5;
            _context.next = 8;
            return axios.post("".concat(baseUrl, "importSettings/"), MEMSOURCE_FILE_IMPORT_SETTINGS, {
              params: {
                token: token
              }
            });

          case 8:
            settingsResponse = _context.sent;
            info(JSON.stringify(settingsResponse.data, null, 2));
            success('Created import settings successfully');
            _context.next = 16;
            break;

          case 13:
            _context.prev = 13;
            _context.t0 = _context["catch"](5);
            bail('Failed to create file import settings' + '\n' + _context.t0);

          case 16:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[5, 13]]);
  }));

  return function createFileImportSettings() {
    return _ref.apply(this, arguments);
  };
}();

module.exports = createFileImportSettings;

==> memsource-cli-3.5.53.tgz: package/lib/create-file-import-settings.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

var axios = require('axios');

var _require = require('./utils'),
    baseUrl = _require.baseUrl,
    authenticate = _require.authenticate;

var _require$setup = require('@cloudflare/cli-helpers').setup({
  cliName: 'memsource-cli'
}),
    bail = _require$setup.bail,
    success = _require$setup.success,
    info = _require$setup.info;

var findConfig = require('find-config');

var config = findConfig.require('memsource.config.js');

var MEMSOURCE_FILE_IMPORT_SETTINGS = config.MEMSOURCE_FILE_IMPORT_SETTINGS;
/**
 * createFileImportSettings
 * Creates settings based on the MEMSOURCE_FILE_IMPORT_SETINGS key
 *
 */

var createFileImportSettings = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
    var response, token, settingsResponse;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            // Bail if we can't find file settings config key
            if (_typeof(MEMSOURCE_FILE_IMPORT_SETTINGS) === undefined) {
              bail('Missing MEMSOURCE_FILE_IMPORT_SETTINGS in memsource.config.js');
            }

            _context.next = 3;
            return authenticate();

          case 3:
            response = _context.sent;
            token = response.data.token;
            _context.prev = 5;
            _context.next = 8;
            return axios.post("".concat(baseUrl, "importSettings/"), MEMSOURCE_FILE_IMPORT_SETTINGS, {
              params: {
                token: token
              }
            });

          case 8:
            settingsResponse = _context.sent;
            info(JSON.stringify(settingsResponse.data, null, 2));
            success('Created import settings successfully');
            _context.next = 16;
            break;

          case 13:
            _context.prev = 13;
            _context.t0 = _context["catch"](5);
            bail('Failed to create file import settings' + '\n' + _context.t0);

          case 16:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[5, 13]]);
  }));

  return function createFileImportSettings() {
    return _ref.apply(this, arguments);
  };
}();

module.exports = createFileImportSettings;
